import request from '@/utils/request'

// 查询直播反馈类型列表
export function listLiveFeedbackType(query) {
  return request({
    url: '/live/liveFeedbackType/list',
    method: 'get',
    params: query
  })
}

// 查询直播反馈类型详细
export function getLiveFeedbackType(typeId) {
  return request({
    url: '/live/liveFeedbackType/' + typeId,
    method: 'get'
  })
}

// 新增直播反馈类型
export function addLiveFeedbackType(data) {
  return request({
    url: '/live/liveFeedbackType',
    method: 'post',
    data: data
  })
}

// 修改直播反馈类型
export function updateLiveFeedbackType(data) {
  return request({
    url: '/live/liveFeedbackType',
    method: 'put',
    data: data
  })
}

// 删除直播反馈类型
export function delLiveFeedbackType(typeId) {
  return request({
    url: '/live/liveFeedbackType/' + typeId,
    method: 'delete'
  })
}
